..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Extension
---------

.. automodule:: invenio_pidstore.ext
   :members:

Models
------

.. automodule:: invenio_pidstore.models
   :members:

Resolver
--------

.. automodule:: invenio_pidstore.resolver
   :members:


Providers
---------

.. automodule:: invenio_pidstore.providers
   :members:

.. automodule:: invenio_pidstore.providers.base
   :members:

.. automodule:: invenio_pidstore.providers.recordid_v2
   :members:

.. automodule:: invenio_pidstore.providers.datacite
  :members:

.. automodule:: invenio_pidstore.providers.recordid
  :members:

Minters
-------

.. automodule:: invenio_pidstore.minters
   :members:

Fetchers
--------

.. automodule:: invenio_pidstore.fetchers
   :members:

Exceptions
----------

.. automodule:: invenio_pidstore.errors
   :members:

CLI
---

Detailed usage documentation is available by running
``inveniomanage pid --help``.

.. automodule:: invenio_pidstore.cli
   :members:
